document.addEventListener('DOMContentLoaded', () => {
  // Smooth scrolling for navigation
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });

  // Parallax effect for hero section
  window.addEventListener('scroll', () => {
    const hero = document.querySelector('.hero');
    const scrolled = window.pageYOffset;
    hero.style.transform = `translateY(${scrolled * 0.5}px)`;
  });

  // Dynamic track hover effects
  const tracks = document.querySelectorAll('.track');
  tracks.forEach(track => {
    track.addEventListener('mouseenter', () => {
      const waveform = track.querySelector('.waveform');
      waveform.style.animation = 'wave 1s ease-in-out infinite';
    });

    track.addEventListener('mouseleave', () => {
      const waveform = track.querySelector('.waveform');
      waveform.style.animation = 'none';
    });
  });

  // Add intersection observer for fade-in animations
  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.classList.add('visible');
      }
    });
  }, { threshold: 0.1 });

  document.querySelectorAll('section').forEach(section => {
    observer.observe(section);
  });
});
